@@ -10,17 +10,21 @@ def ensure_list(something: Any) -> list[Any]:
     This is intended to use so that where column names should be provided
     as a list could also be provided as a single column name
 
-    >>> ensure_list("abc")
-    ["abc"]
+        Examples:
+        >>> ensure_list("abc")
+        ["abc"]
 
-    >>> ensure_list({"a", "b"})
-    ["a", "b"]
+        >>> ensure_list({"a", "b"})
+        ["a", "b"]
 
-    >>> ensure_list(1)
-    [1]
+        >>> ensure_list(1)
+        [1]
 
-    something:  the value to be in or the list
-    returns:    a list of whatever something is
+    Args:
+        something:  the value to be in or the list
+
+    Returns:
+        a list of whatever something is
     """
     # strings are iterables, so here is a special case for them
     if isinstance(something, str):
@@ -35,8 +39,15 @@ def ensure_list(something: Any) -> list[Any]:
 def check_columns_exist(data: pandas.DataFrame, *arguments) -> bool:
     """raises KeyError if columns dont exist in a data frame
 
-    data       : the pandas DataFrame to check for
-    *arguments : variatic number of columns or lists of columns to check
+    Args:
+        data       : the pandas DataFrame to check
+        *arguments : variatic number of columns or lists of columns to check
+
+    Returns:
+        True if all columns exist in the data frame
+
+    Raises:
+        KeyError: if any column does not exist in the data frame
     """
     argument_items_as_lists = (ensure_list(arg) for arg in arguments)
     check_cols = set(itertools.chain.from_iterable(argument_items_as_lists))
